@@ -7,41 +7,23 @@ from tasq_cli.server import make_request
 
 logger = None
 
-def make_request(url, post_data={}):
-    logger.info(f'request {url=} {post_data=}')
-    full_url = SERVER + url
-    headers={'Authorization': f'BEARER {TOKEN}'}
-    if post_data:
-        r = requests.post(
-            full_url,
-            headers={'Authorization': f'BEARER {TOKEN}'},
-            data = post_data
-        )
-    else:
-        r = requests.get(
-            full_url,
-            headers=headers
-        )
-    if not 200 <= r.status_code < 400:
-        r.raise_for_status()
-    return r
-
 def run_job(args):
     global logger
     logger = settings.get_logger()
     url = f'/jobs'
     tag = args.tag
-    data = {
-        "name": "",
-        "include_model": False,
-        "tags": [f"{tag}"],
-        "exclude_tags": [],
-        "max_resources": None,
-        "for_qualification": False,
-        "project_id": args.project_id,
-        "project_resource_ids": []
-    }
-    r = make_request(url, post_data=data)
+    headers = {'content-type': 'application/vnd.api+json', 'accept': 'application/vnd.api+json'}
+
+    data = {'data': {'type': 'jobs',
+              'attributes': {'name': '',
+                             'includeModel': False,
+                             'tags': [tag],
+                             'excludeTags': [],
+                             'maxResources': None,
+                             'forQualification': False,
+                             'projectId': args.project_id,
+                             'projectResourceIds': []}}}
+    r = make_request(url, headers=headers, json=data)
     data = r.json()['data']
     del data['relationships']
     print(data)
@@ -60,27 +42,6 @@ def list_jobs(args):
     return
 
 
-def run_job(args):
-    global logger
-    logger = settings.get_logger()
-    url = f'/jobs'
-    tag = args.tag
-    data = {
-        "name": "",
-        "include_model": False,
-        "tags": [f"{tag}"],
-        "exclude_tags": [],
-        "max_resources": None,
-        "for_qualification": False,
-        "project_id": args.project_id,
-        "project_resource_ids": []
-    }
-    r = make_request(url, post_data=data)
-    data = r.json()['data']
-    del data['relationships']
-    print(data)
-    return
-
 def export_job(args):
     global logger
     logger = settings.get_logger()
