@@ -251,19 +251,22 @@ def upload_csv(args):
     dataset_id = r.json()['data']['attributes']['datasetId']
     headers={'content-type': 'application/vnd.api+json', 'accept':'application/vnd.api+json'}
 
-    r = make_request('/source_files', headers=headers, json=
-        {
-            "data": {
-            "type":"source_files",
+    post_data = {
+        "data": {
+            "type": "source_files",
             "attributes": {
                 "file": {
-                    "type":"GenericFile",
-                     "id": generic_file_id
+                    "type": "GenericFile",
+                    "id": generic_file_id
                 },
-                "dataset":{
-                    "type":"dataset",
+                "dataset": {
+                    "type": "dataset",
                     "id": dataset_id
                 }
             }
-        }})
+        }
+    }
+    if args.tag:
+        post_data['data']['attributes']['tag_name'] = args.tag
+    r = make_request('/source_files', headers=headers, json=post_data)
 
